"""
Модуль для получения изображения/видео дня с сайта NASA.
Публикация с помощью бота полученных данных в созданный
для этого канал. Требует установки библиотек aiogram и nasapy,
а также selenium bs4 lxml pandas
pip install aiogram nasapy selenium bs4 lxml pandas
"""

import time
from datetime import datetime

import nasapy
from aiogram import Bot, Dispatcher, executor, types
from aiogram.utils.markdown import hbold, hlink, hspoiler, text

from config import token, id_channel, nasa_key
from deep import browser_get_html

bot = Bot(token=token, parse_mode=types.ParseMode.HTML)
dp = Dispatcher(bot)


def nasa_image(date):
    """
    Создаем экземпляр класса Nasa, в который передаем
    текущую дату и параметр для получения фото в высоком
    разрешении.
    Забираем из полученных данных ссылку, описание и заголовок.
    Запускаем модуль перевода текста с помощью переводчика Deep_L,
    передаем ему описание, получаем в ответ перевод.
    :param date: Текущая дата, для получения изображения/видео.
    :return: Возвращаем ссылку, описание, заголовок.
    """
    nasa = nasapy.Nasa(key=nasa_key)
    apod = nasa.picture_of_the_day(date=date, hd=True)
    url = apod['url']
    text_ex = apod['explanation']
    explanation = browser_get_html(text_ex)
    title = apod['title']
    return url, explanation, title


@dp.message_handler(commands="start")
async def start(message: types.Message):
    """
    При запуске бота получаем сообщение. Запускаем функцию.
    В функции запускаем бесконечный цикл, в котором будем
    получать текущую дату, а затем отправлять ее в функцию
    получения изображения или видео. Из функции возвращается
    ссылка на изображение/видео, описание, заголовок.
    Отправляем сообщение боту, который пересылает его в
    созданный канал, администратором которого он является.
    После чего засыпаем на 24 часа.
    :param message: Сообщение для запуска бота "/start".
    """
    while True:
        date_now = datetime.today().strftime('%Y-%m-%d')
        url, explanation, title = nasa_image(date_now)
        await bot.send_message(id_channel, f'{hbold(date_now)}\n\n{hlink(title, url)}\n\n{text(explanation)}\n\n')
        time.sleep(86400)


if __name__ == "__main__":
    """
    Запускаем бота. Передаем в функцию 
    объект диспетчера, который создан ранее
    и содержит, в свою очередь объект бота,
    в котором передается токен и задается режим
    отображения сообщений.
    """
    executor.start_polling(dp)
